@@ -3,7 +3,7 @@ use warnings;
 
 package JMAP::Tester;
 # ABSTRACT: a JMAP client made for testing JMAP servers
-$JMAP::Tester::VERSION = '0.022';
+$JMAP::Tester::VERSION = '0.023';
 use Moo;
 
 use Crypt::Misc qw(decode_b64u encode_b64u);
@@ -151,6 +151,19 @@ sub _set_cookie {
   );
 }
 
+#pod =attr default_using
+#pod
+#pod This is an arrayref of strings that specify which capabilities the client
+#pod wishes to use. (See L<https://jmap.io/spec-core.html#the-request-object>
+#pod for more info). By default, JMAP::Tester will not send a 'using' parameter.
+#pod
+#pod =cut
+
+has default_using => (
+  is => 'rw',
+  predicate => '_has_default_using',
+);
+
 #pod =attr default_arguments
 #pod
 #pod This is a hashref of arguments to be put into each method call.  It's
@@ -258,6 +271,10 @@ sub request {
   $request = $request->{methodCalls}
     if $ENV{JMAP_TESTER_NO_WRAPPER} && _ARRAY0($input_request);
 
+  if ($self->_has_default_using && ! exists $request->{using}) {
+    $request->{using} = $self->default_using;
+  }
+
   my $json = $self->json_encode($request);
 
   my $post = HTTP::Request->new(
@@ -790,7 +807,7 @@ JMAP::Tester - a JMAP client made for testing JMAP servers
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 OVERVIEW
 
@@ -843,6 +860,12 @@ There is also L<JMAP::Tester::Response/"as_stripped_pairs">.
 
 =head1 ATTRIBUTES
 
+=head2 default_using
+
+This is an arrayref of strings that specify which capabilities the client
+wishes to use. (See L<https://jmap.io/spec-core.html#the-request-object>
+for more info). By default, JMAP::Tester will not send a 'using' parameter.
+
 =head2 default_arguments
 
 This is a hashref of arguments to be put into each method call.  It's
@@ -965,6 +988,10 @@ Alfie John <alfiej@fastmail.fm>
 
 =item *
 
+Matthew Horsfall <alh@fastmailteam.com>
+
+=item *
+
 Matthew Horsfall <wolfsage@gmail.com>
 
 =item *
